@@ -272,6 +272,9 @@ func mergeConfig(config *libconfig.Config, ctx *cli.Context) error {
 	if ctx.IsSet("stream-tls-key") {
 		config.StreamTLSKey = ctx.String("stream-tls-key")
 	}
+	if ctx.IsSet("stream-idle-timeout") {
+		config.StreamIdleTimeout = ctx.String("stream-idle-timeout")
+	}
 	if ctx.IsSet("version-file") {
 		config.VersionFile = ctx.String("version-file")
 	}
@@ -294,6 +297,10 @@ func mergeConfig(config *libconfig.Config, ctx *cli.Context) error {
 		config.SeparatePullCgroup = ctx.String("separate-pull-cgroup")
 	}
 
+	if ctx.IsSet("infra-ctr-cpuset") {
+		config.InfraCtrCPUSet = ctx.String("infra-ctr-cpuset")
+	}
+
 	return nil
 }
 
@@ -639,6 +646,11 @@ func getCrioFlags(defConf *libconfig.Config) []cli.Flag {
 			Usage:   "Port for the pprof profiler",
 			EnvVars: []string{"CONTAINER_PROFILE_PORT"},
 		},
+		&cli.BoolFlag{
+			Name:    "enable-profile-unix-socket",
+			Usage:   "Enable pprof profiler on crio unix domain socket",
+			EnvVars: []string{"ENABLE_PROFILE_UNIX_SOCKET"},
+		},
 		&cli.BoolFlag{
 			Name:    "enable-metrics",
 			Usage:   "Enable metrics endpoint for the server on localhost:9090",
@@ -780,6 +792,11 @@ func getCrioFlags(defConf *libconfig.Config) []cli.Flag {
 			EnvVars:   []string{"CONTAINER_TLS_KEY"},
 			TakesFile: true,
 		},
+		&cli.StringFlag{
+			Name:    "stream-idle-timeout",
+			Usage:   "Length of time until open streams terminate due to lack of activity",
+			EnvVars: []string{"STREAM_IDLE_TIMEOUT"},
+		},
 		&cli.StringFlag{
 			Name:        "registries-conf",
 			Usage:       "path to the registries.conf file",
@@ -802,6 +819,11 @@ func getCrioFlags(defConf *libconfig.Config) []cli.Flag {
 			EnvVars:   []string{"CONTAINER_VERSION_FILE_PERSIST"},
 			TakesFile: true,
 		},
+		&cli.StringFlag{
+			Name:    "infra-ctr-cpuset",
+			Usage:   "CPU set to run infra containers, if not specified CRI-O will use all online CPUs to run infra containers (default: '').",
+			EnvVars: []string{"CONTAINER_INFRA_CTR_CPUSET"},
+		},
 	}
 }
 
